"use client";
import React, { useState, useEffect, useCallback } from 'react';
import axios from '@/services/APIservices';

const fallbackCities = [
  { name: "Noida", info: "1240+ land", image: "/cities/chennai.png" },
  { name: "Delhi", info: "1240+ land", image: "/cities/delhi.png" },
  { name: "Dholera sir", info: "1240+ land", image: "/cities/dholera.png" },
  { name: "Faridabad", info: "1240+ land", image: "/cities/mumbai.png" },
  { name: "Pune", info: "1240+ land", image: "/cities/pune.png" },
];

const POLLING_INTERVAL = 10000; // 10 seconds for more frequent updates

const Available = () => {
  const [cities, setCities] = useState(fallbackCities);
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState(null);

  const transformCityData = (cityData) => ({ 
    name: cityData.city,
    info: `${cityData.count}+ land`,
    image: `/cities/${cityData.city.toLowerCase()}.png`
  });

  const fetchCities = useCallback(async () => {
    try {
      const response = await axios.get('api/post-by-cities');
      
      if (Array.isArray(response.data)) {
        const transformedCities = response.data.map(transformCityData);
        setCities(transformedCities);
        setError(null);
      } else {
        throw new Error("Invalid data format from server");
      }
    } catch (err) {
      console.error('Error fetching cities:', err);
      if (!cities.length) {
        setCities(fallbackCities);
      }
      setError("Unable to fetch cities data. Showing last known data.");
    }
  }, [cities.length]);

  // Initial fetch
  useEffect(() => {
    setIsLoading(true);
    fetchCities().finally(() => setIsLoading(false));
  }, [fetchCities]);

  // Set up continuous polling for real-time updates
  useEffect(() => {
    const pollInterval = setInterval(fetchCities, POLLING_INTERVAL);
    return () => clearInterval(pollInterval);
  }, [fetchCities]);

  const handleImageError = (e) => {
    e.currentTarget.src = '/placeholder-image.png';
  };

  return (
    <section className="w-full max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8 sm:py-12 mt-8 sm:mt-12 lg:mt-16">
      <div className="flex flex-col sm:flex-row justify-between items-center gap-4 mb-6 sm:mb-8">
        <div className="w-full sm:w-auto text-center sm:text-left">
          <h2 className="text-lg sm:text-xl lg:text-2xl font-semibold text-tertiary">
            We are available in many well-known cities
          </h2>
        </div>
        <button 
          className="bg-brand py-2 px-3 sm:px-4 rounded-lg flex-shrink-0 hover:opacity-90 transition-opacity"
          aria-label="View more cities"
        >
          <img 
            src="/icons/right-arrow.png" 
            alt="Arrow" 
            className="w-2.5 sm:w-3 h-5 sm:h-6"
          />
        </button>
      </div>

      {error && (
        <div className="w-full text-red-500 text-center bg-red-50 p-3 sm:p-4 rounded-lg text-sm sm:text-base mb-6">
          {error}
        </div>
      )}

      {isLoading ? (
        <div className="flex justify-center items-center min-h-[200px]">
          <div className="animate-spin rounded-full h-6 w-6 sm:h-8 sm:w-8 border-b-2 border-brand"></div>
        </div>
      ) : (
        <div className="grid grid-cols-1 xs:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 gap-3 sm:gap-4 lg:gap-6">
          {cities.map((city, index) => (
            <div 
              key={index}
              className="flex gap-2 sm:gap-3 lg:gap-4 uppercase items-center p-2 sm:p-3 hover:bg-gray-50 rounded-lg transition-colors border border-gray-100"
            >
              <div className="relative w-10 h-10 sm:w-12 sm:h-12 lg:w-[131px] lg:h-[121px] flex-shrink-0">
                <img
                  src={city.image}
                  alt={`${city.name} city`}
                  onError={handleImageError}
                  className="absolute inset-0 w-full h-full object-cover rounded-lg"
                  loading="lazy"
                />
              </div>
              
              <div className="min-w-0 flex-1">
                <p className="font-semibold truncate text-gray-900 text-sm sm:text-base">
                  {city.name}
                </p>
                <p className="text-tertiary text-xs sm:text-sm lg:text-base truncate">
                  {city.info}
                </p>
              </div>
            </div>
          ))}
        </div>
      )}
    </section>
  );
};

export default Available;